Welcome to socketsundso
=======================

.. automodule:: socketsundso
   :noindex:
.. warning::
   This project is in very early development and not ready for general usage.

   There **will** be a lot of breaking changes before we reach version 0.1.0.


Welcome to socketsundso's documentation. There is currently not much here, but I hope that'll change. For now just take a look around and I highly recommend you look at the examples in the examples/ directory.

socketsundso is based on `FastAPI`_, `Starlette`_ and `pydantic`_. So you should propably read their documentation too.

.. _FastAPI: https://fastapi.tiangolo.com/
.. _Starlette: https://www.starlette.io/
.. _pydantic: https://pydantic-docs.helpmanual.io/

User's Guide
------------

.. warning:: Like everything in this project the `User's Guide` is an early draft.

.. toctree::
   :maxdepth: 3

   foreword
   tutorial

API Reference
-------------

Here you can find all the information about the function, classes and methods of socketsundso.

.. toctree::
   :maxdepth: 3

   api

Additional Notes
----------------

.. toctree::
   :maxdepth: 2

   changes
